# Iteration Checkpoint (Step {step})

Before continuing, please confirm:

1. **Is the problem solved?** If yes, provide the final answer

2. **What progress have you made?** What tasks are completed? What's remaining?

3. **What's your next step?** Be specific about what you're going to do

## Important Reminders

- When you say you'll call a tool, ACTUALLY call it
- Do NOT end your turn without fully solving the problem
- If you need more information, continue using tools to gather it
